import React from 'react';
import ReactDOM from 'react-dom/client';
import './index.css';
import sha256 from 'crypto-js/sha256';

import LoggedView from './loggedView';

const { Component } = React

export const hostProfile = 'http://'+ process.env.REACT_APP_API_HOST;

class App extends React.Component {
  
    constructor(props){
      super(props);
      this.state = {
        repos: []
      };
    }
    
    render(){
      return (
        <div className="app-container">
          <h3><a href='/'>Network Connected App - FrontEnd</a></h3>
          <EntryPage handleSubmit={this.profilesLogin} />
          <span><small>[You are running this application in <b>{process.env.NODE_ENV}</b> mode.]</small></span>
          <p/>
          <span><small>&#169; 2022 - Jordi Catalán</small></span>
        </div>
      )
    }
  }

class EntryPage extends Component {
  constructor(props){
    super(props)
    this.state = {
      currentView: "logIn",
      token: "NULL",
      profile: {},
      msg: ""
    }

  }

  hash = (string) => {
    const hash = sha256(string).toString();

    return hash.toUpperCase();
  }

  profilesLoginReg = (username, pwd, details = '') => {
    let url = hostProfile + '/api/profiles/session';
    let loginMode=(details === '');

    var myHeaders = new Headers();
        if (loginMode) {
            myHeaders.append("Content-Type", "application/x-www-form-urlencoded");
        } else {
            myHeaders.append("Content-Type", "application/json");
            url =  hostProfile + '/api/profiles';
        }
        myHeaders.append("Accept", "application/json");
        myHeaders.append("Connection", "keep-alive");

    var urlencoded = new URLSearchParams();
        urlencoded.append("name", username);
        urlencoded.append("password",this.hash(pwd));
    
    var bodyReq= urlencoded;
    if (! loginMode) {
        bodyReq = JSON.stringify({
            "username": username,
            "details": details,
            "password": this.hash(pwd)
          });
          
    }

    var requestOptions = {
        method: 'POST',
        headers: myHeaders,
        body: bodyReq,
        redirect: 'follow'
        };

    this.setState({
            currentView: this.state.currentView,
            token: "NULL",
            profile: {},
            msg: ""
    })
    console.log("Calling url POST:"+ url);
    fetch(url, 
            requestOptions)
            .then((response) => {
                if (response.status === 204) {
                    return;
                } else if (response.ok) {
                    return response.json();
                } else {
                    console.log('warning', 'Not auhorized');
                    
                    throw Error;
                }
            })
            .then((result) => {
                
                if (loginMode) {
                    console.log('result:'+result);
                    console.log('token=' + result.token + ", profile="+ result.profile);
                    this.setState({
                        currentView: 'Logged',
                        token: result.token,
                        profile: result.profile,
                        msg: ''
                    });
                } else {
                    this.changeView('logIn');
                }
            })
            .catch((error) => {
                console.log('error', error);
                //this.state.msg= 'Not auhorized';
                this.setState({
                    currentView: 'logIn',
                    msg: 'Not auhorized'
                });
            });


  }


  handleSubmit = (event) => {
    event.preventDefault();
    
    const pwd= event.target.password.value;
    //console.log("username:" + username);
    switch(this.state.currentView) {
        case "signUp":
            const username = event.target.username.value;
            const details= event.target.details.value;
            console.log("REGISTER FORM");
            this.profilesLoginReg(username, pwd, details);
            break;
        case "logIn":
            const username2 = event.target.username.value;
            console.log("LOGIN FORM");
            //this.props.profilesLogin(username, pwd);
            this.profilesLoginReg(username2, pwd);
            break;
        default:
            break;
    }
    
  };

  changeView = (view) => {
    this.setState({
      currentView: view
    })
  }


  currentView = () => {
    

    switch(this.state.currentView) {
      case "signUp":
        return (
          <form onSubmit={this.handleSubmit}>
            <h2>Sign Up!</h2>
            <fieldset>
              <legend>Create Account</legend>
              <ul>
                <li>
                  <label htmlFor="username">Username:</label>
                  <input type="text" id="username" minLength="8" maxLength="16" required/>
                </li>
                <li>
                  <label htmlFor="details">Details:</label>
                  <input type="text" id="details"  maxLength="256"  />
                </li>
                <li>
                  <label htmlFor="password">Password:</label>
                  <input type="password" id="password" maxLength="64" required/>
                </li>
              </ul>
            </fieldset>
            <button type='Submit'>Submit</button>
            <button type="button" onClick={ () => this.changeView("logIn")}>Have an Account?</button>
          </form>
        )
        // eslint-disable-next-line
        break;

      case "logIn":
        return (
          <form onSubmit={this.handleSubmit}>
            <h2>Welcome Back!</h2>
            <fieldset>
              <legend>Log In</legend>
              <ul>
                <li>
                  <label htmlFor="username">Username:</label>
                  <input type="text" id="username" required/>
                </li>
                <li>
                  <label htmlFor="password">Password:</label>
                  <input type="password" id="password" maxLength="64" required/>
                </li>
              </ul>
            </fieldset>
            alert= 
            {this.showMessage()}
            <button type="submit">Login</button>
            <button type="button" onClick={ () => this.changeView("signUp")}>Create an Account</button>

          </form>
          
        )
        // eslint-disable-next-line
        break;
      case "Logged":

          return (
              <LoggedView token={this.state.token} profile={this.state.profile}/>
          );
          // eslint-disable-next-line
          break;
      default:
        break;
    }
  }

  showMessage = () => {
    if (this.state.msg === "") {
        return (<p/>);
    } else {
        return (
            <div id="alert">
                <span >{this.state.msg}</span>
            </div>
        );
    }
  }

  render() {
    return (
      <section id="entry-page">
        {this.currentView()}
      </section>
    )
  }
}

const root = ReactDOM.createRoot(document.getElementById('app'));
root.render(<App />);