import React from "react";

const host = 'http://'+ process.env.REACT_APP_API_HOST;

class Weather extends React.Component {

    constructor(props)
    {
        super(props);
        this.state = { token : '',
                        location: '',
                        weatherJSON: {}
                     };
    }

    weatherSubmit = (locationParam = '') => {
        const encodedValue = encodeURIComponent(locationParam);
        let url = host + '/api/weather?q='+ encodedValue;
        
    
        var myHeaders = new Headers();
            myHeaders.append("Content-Type", "application/json");
            
            myHeaders.append("Accept", "application/json");
            myHeaders.append("Connection", "keep-alive");
            myHeaders.append("token", this.props.token);
    
        var requestOptions = {
            method: 'GET',
            headers: myHeaders,
            redirect: 'follow'
            };
    
    
        console.log("Calling url GET: "+ url);
        fetch(url, 
                requestOptions)
                .then((response) => {
                    if (response.ok) {
                        return response.json();
                    } else {
                        console.log('warning', 'Not auhorized');
                        
                        throw Error;
                    }
                })
                .then((result) => {
                    
                    console.log('result:'+result);
                    console.log("GET weather="+ result.toString());
                    this.setState({
                        token: this.props.token,
                        location: locationParam,
                        weatherJSON: result
                    })
                })
                .catch((error) => {
                    console.log('error', error);
                });
      }



    render() {
        return (
            <React.Fragment>
                <h2>Search weather</h2>
                <WeatherSearch handleSubmit={this.weatherSubmit}/>
                <WeatherResult weather={this.state.weatherJSON} />
            </React.Fragment>
        )
    }
}
class WeatherResult extends React.Component {

    constructor(props)
    {
        super(props);
    }

    render() {
        //return ('');
        if (this.props.weather && this.props.weather!== {} && Object.keys(this.props.weather).length>0) {
            var weatJSON= this.props.weather;
            let temp= weatJSON.main.temp;
            let city= weatJSON.name;
            let cel= weatJSON.weather[0].description;

            console.log("temp: "+temp);

            return (
                <div id="result">
                    <fieldset>
                        <legend>Weather Info</legend>
                        <ul>
                            <li>
                                <label >{city}: {temp}ºC {cel}</label>
                            </li>
                        </ul>
                    </fieldset>
                </div>
            );
        } else {
            return ('');
        };

    }


}

class WeatherSearch extends React.Component {

    constructor(props)
    {
        super(props);
        this.state = { token : '',
                        location: '',
                        weatherJSON: {}
                     };
    }

      handleSubmit = (event) => {
        event.preventDefault();
        if (event.target.location) {
            const text = event.target.location.value;
            if (text && text !== ''){
                this.props.handleSubmit(text);
            };
        } else {
            console.log("location invalid or undefined");
        }
      }

    render() {
        return( 
            <div id="weather" >
                <form onSubmit={this.handleSubmit}>
                    <fieldset>
                        <legend>Weather</legend>
                        <ul>
                            <li>
                            <label htmlFor="location">Location:</label>
                            <input type="text" id="location" name="location" required/>
                            </li>
                        </ul>
                    </fieldset>
                </form>
            </div>
        )
    }
}

export default Weather;